Module constraint

Module constraint 

Modules

result
stock
Types that impl Constraint that are included with Simulacrum.

Structs

ConstraintMock

Enums

ConstraintError

Traits

Constraint
A Constraint is a type that can be added to an Expectation.

Type Aliases

ConstraintResult
The Error type is a message to be printed to the user.