pub type ConstraintResult = Result<(), ConstraintError>;Expand description
The Error type is a message to be printed to the user.
Aliased Type
pub enum ConstraintResult {
Ok(()),
Err(ConstraintError),
}pub type ConstraintResult = Result<(), ConstraintError>;The Error type is a message to be printed to the user.
pub enum ConstraintResult {
Ok(()),
Err(ConstraintError),
}