Modules
Structs
Enums
Traits
- Constraint
- A
Constraintis a type that can be added to anExpectation.
Type Aliases
- Constraint
Result - The Error type is a message to be printed to the user.
Constraint is a type that can be added to an Expectation.